;; Generated package description from solarized-theme.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "solarized-theme" "2.1.0.0.20260610.7" "The Solarized color theme" '((emacs "24.1")) :commit "0d9d9efff196d8d8ee4ac606e70bf062a057136b" :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev")) :maintainer '("Bozhidar Batsov" . "bozhidar@batsov.dev") :keywords '("convenience" "themes" "solarized") :url "http://github.com/bbatsov/solarized-emacs")
